#' The 'rcbayes' package.
#' @aliases rcbayes-package
"_PACKAGE"
#'
#' @description A DESCRIPTION OF THE PACKAGE
#'
#' @name rcbayes-package
#' @aliases rcbayes
#' @useDynLib rcbayes, .registration = TRUE
#' @import methods
#' @import Rcpp
#' @importFrom rstan sampling
#'
#' @references
#' Stan Development Team (2020). RStan: the R interface to Stan. R package version 2.21.2. https://mc-stan.org
#'
NULL
